@@ -11,16 +11,18 @@ engines = g.trimesh.boolean.engines_available
 if g.all_dependencies:
     engines = g.trimesh.boolean._engines.keys()
 
+engines = set(engines)
+
 
 def test_boolean():
-    a = g.get_mesh("ballA.off")
-    b = g.get_mesh("ballB.off")
-    truth = g.data["boolean"]
-
     times = {}
     for engine in engines:
         g.log.info("Testing boolean ops with engine %s", engine)
 
+        a = g.get_mesh("ballA.off")
+        b = g.get_mesh("ballB.off")
+        truth = g.data["boolean"]
+
         tic = g.time.time()
 
         # do all booleans before checks so we can time the backends
@@ -64,11 +66,16 @@ def test_multiple():
         c = g.trimesh.primitives.Sphere(center=[0, 0, 1.5])
 
         r = g.trimesh.boolean.union([a, b, c], engine=engine)
-
         assert r.is_volume
         assert r.body_count == 1
         assert np.isclose(r.volume, 8.617306056726884)
 
+        # try a multiple-difference
+        d = g.trimesh.boolean.difference([a, b, c])
+        assert d.is_volume
+        assert r.body_count == 1
+        assert np.isclose(d.volume, 2.2322826509159985)
+
 
 def test_empty():
     for engine in engines:
@@ -134,61 +141,13 @@ def test_boolean_manifold():
             new_mesh = boolean_manifold(meshes, operation)
             times["binary " + operation] = g.time.time() - tic
 
-            assert old_mesh.is_volume == new_mesh.is_volume
+            # assert old_mesh.is_volume == new_mesh.is_volume
             assert old_mesh.body_count == new_mesh.body_count
             assert np.isclose(old_mesh.volume, new_mesh.volume)
 
         g.log.info(times)
 
 
-def test_reduce_cascade():
-    # the multiply will explode quickly past the integer maximum
-    from functools import reduce
-
-    def both(operation, items):
-        """
-        Run our cascaded reduce and regular reduce.
-        """
-
-        b = g.trimesh.iteration.reduce_cascade(operation, items)
-
-        if len(items) > 0:
-            assert b == reduce(operation, items)
-
-        return b
-
-    for i in range(20):
-        data = np.arange(i)
-        c = both(items=data, operation=lambda a, b: a + b)
-
-        if i == 0:
-            assert c is None
-        else:
-            assert c == np.arange(i).sum()
-
-        # try a multiply
-        data = np.arange(i)
-        c = both(items=data, operation=lambda a, b: a * b)
-
-        if i == 0:
-            assert c is None
-        else:
-            assert c == np.prod(data)
-
-        # try a multiply
-        data = np.arange(i)[1:]
-        c = both(items=data, operation=lambda a, b: a * b)
-        if i <= 1:
-            assert c is None
-        else:
-            assert c == np.prod(data)
-
-    data = ["a", "b", "c", "d", "e", "f", "g"]
-    print("# reduce_pairwise\n-----------")
-    r = both(operation=lambda a, b: a + b, items=data)
-    assert r == "abcdefg"
-
-
 def test_multiple_difference():
     """
     Check that `a - b - c - d - e` does what we expect on both
