@@ -815,7 +815,9 @@ class GLTFTest(g.unittest.TestCase):
         magenta = g.np.array([255, 0, 255, 255], dtype=g.np.uint8)
         for color in mesh.visual.vertex_colors:
             is_magenta = g.np.array_equal(color, magenta)
-            assert is_magenta, f"Imported vertex color is not of expected value: got {color}, expected {magenta}"
+            assert is_magenta, (
+                f"Imported vertex color is not of expected value: got {color}, expected {magenta}"
+            )
 
     def test_export_postprocess(self):
         scene = g.trimesh.Scene()
