@@ -6,6 +6,8 @@ The base class for Trimesh, PointCloud, and Scene objects
 """
 
 import abc
+import os
+from dataclasses import dataclass
 
 import numpy as np
 
@@ -13,10 +15,56 @@ from . import bounds, caching
 from . import transformations as tf
 from .caching import cache_decorator
 from .constants import tol
-from .typed import Dict, Optional
+from .resolvers import ResolverLike
+from .typed import Any, ArrayLike, Dict, NDArray, Optional, float64
 from .util import ABC
 
 
+@dataclass
+class LoadSource:
+    """
+    Save information about where a particular object was loaded from.
+    """
+
+    # a file-like object that can be accessed
+    file_obj: Optional[Any] = None
+
+    # a cleaned file type string, i.e. "stl"
+    file_type: Optional[str] = None
+
+    # if this was originally loaded from a file path
+    # save it here so we can check it later.
+    file_path: Optional[str] = None
+
+    # did we open `file_obj` ourselves?
+    was_opened: bool = False
+
+    # a resolver for loading assets next to the file
+    resolver: Optional[ResolverLike] = None
+
+    @property
+    def file_name(self) -> Optional[str]:
+        """
+        Get just the file name from the path if available.
+
+        Returns
+        ---------
+        file_name
+          Just the file name, i.e. for file_path="/a/b/c.stl" -> "c.stl"
+        """
+        if self.file_path is None:
+            return None
+        return os.path.basename(self.file_path)
+
+    def __getstate__(self) -> Dict:
+        # this overrides the `pickle.dump` behavior for this class
+        # we cannot pickle a file object so return `file_obj: None` for pickles
+        return {k: v if k != "file_obj" else None for k, v in self.__dict__.items()}
+
+    def __deepcopy__(self, *args):
+        return LoadSource(**self.__getstate__())
+
+
 class Geometry(ABC):
     """
     `Geometry` is the parent class for all geometry.
@@ -29,18 +77,37 @@ class Geometry(ABC):
     # geometry should have a dict to store loose metadata
     metadata: Dict
 
+    @property
+    def source(self) -> LoadSource:
+        """
+        Where and what was this current geometry loaded from?
+
+        Returns
+        --------
+        source
+          If loaded from a file, has the path, type, etc.
+        """
+        # this should have been tacked on by the loader
+        # but we want to *always* be able to access
+        # a value like `mesh.source.file_type` so add a default
+        current = getattr(self, "_source", None)
+        if current is not None:
+            return current
+        self._source = LoadSource()
+        return self._source
+
     @property
     @abc.abstractmethod
-    def bounds(self):
+    def bounds(self) -> NDArray[np.float64]:
         pass
 
     @property
     @abc.abstractmethod
-    def extents(self):
+    def extents(self) -> NDArray[np.float64]:
         pass
 
     @abc.abstractmethod
-    def apply_transform(self, matrix):
+    def apply_transform(self, matrix: ArrayLike) -> Any:
         pass
 
     @property
@@ -54,10 +121,10 @@ class Geometry(ABC):
 
         Returns
         ---------
-        hash : int
+        hash
           Hash of current graph and geometry.
         """
-        return self._data.__hash__()
+        return self._data.__hash__()  # type: ignore
 
     @abc.abstractmethod
     def copy(self):
@@ -75,7 +142,7 @@ class Geometry(ABC):
     def export(self, file_obj, file_type=None):
         pass
 
-    def __repr__(self):
+    def __repr__(self) -> str:
         """
         Print quick summary of the current geometry without
         computing properties.
@@ -103,7 +170,7 @@ class Geometry(ABC):
             elements.append(f"name=`{display}`")
         return "<trimesh.{}({})>".format(type(self).__name__, ", ".join(elements))
 
-    def apply_translation(self, translation):
+    def apply_translation(self, translation: ArrayLike):
         """
         Translate the current mesh.
 
@@ -230,8 +297,7 @@ class Geometry3D(Geometry):
         # translate to center of axis aligned bounds
         transform[:3, 3] = self.bounds.mean(axis=0)
 
-        aabb = primitives.Box(transform=transform, extents=self.extents, mutable=False)
-        return aabb
+        return primitives.Box(transform=transform, extents=self.extents, mutable=False)
 
     @caching.cache_decorator
     def bounding_box_oriented(self):
@@ -248,10 +314,9 @@ class Geometry3D(Geometry):
         from . import bounds, primitives
 
         to_origin, extents = bounds.oriented_bounds(self)
-        obb = primitives.Box(
+        return primitives.Box(
             transform=np.linalg.inv(to_origin), extents=extents, mutable=False
         )
-        return obb
 
     @caching.cache_decorator
     def bounding_sphere(self):
@@ -272,8 +337,7 @@ class Geometry3D(Geometry):
         from . import nsphere, primitives
 
         center, radius = nsphere.minimum_nsphere(self)
-        minball = primitives.Sphere(center=center, radius=radius, mutable=False)
-        return minball
+        return primitives.Sphere(center=center, radius=radius, mutable=False)
 
     @caching.cache_decorator
     def bounding_cylinder(self):
@@ -288,8 +352,7 @@ class Geometry3D(Geometry):
         from . import bounds, primitives
 
         kwargs = bounds.minimum_cylinder(self)
-        mincyl = primitives.Cylinder(mutable=False, **kwargs)
-        return mincyl
+        return primitives.Cylinder(mutable=False, **kwargs)
 
     @caching.cache_decorator
     def bounding_primitive(self):
@@ -311,10 +374,9 @@ class Geometry3D(Geometry):
             self.bounding_cylinder,
         ]
         volume_min = np.argmin([i.volume for i in options])
-        bounding_primitive = options[volume_min]
-        return bounding_primitive
+        return options[volume_min]
 
-    def apply_obb(self, **kwargs):
+    def apply_obb(self, **kwargs) -> NDArray[float64]:
         """
         Apply the oriented bounding box transform to the current mesh.
 
@@ -343,7 +405,7 @@ class Geometry3D(Geometry):
 
         if tol.strict:
             # obb transform should not have changed volume
-            if hasattr(self, "volume"):
+            if hasattr(self, "volume") and getattr(self, "is_watertight", False):
                 assert np.isclose(self.volume, volume)
             # overall extents should match what we expected
             assert np.allclose(self.extents, extents)
